Index — Pootle 2.5.0-rc1 documentation

# Index

A | C | D | E | F | L | M | O | P | S | T | U | V

## A

AMAGAMA_URL setting AUTH_LDAP_ANON_DN setting AUTH_LDAP_ANON_PASS setting AUTH_LDAP_BASE_DN setting | AUTH_LDAP_FIELDS setting AUTH_LDAP_FILTER setting AUTH_LDAP_SERVER setting AUTOSYNC setting

## C

CAN_CONTACT setting CAN_REGISTER setting | CONTACT_EMAIL setting CUSTOM_TEMPLATE_CONTEXT setting

## D

DESCRIPTION setting

## E

EMAIL_SEND_HTML setting ENABLE_ALT_SRC setting | EXPORTED_DIRECTORY_MODE setting EXPORTED_FILE_MODE setting

## F

FUZZY_MATCH_MAX_LENGTH setting | FUZZY_MATCH_MIN_SIMILARITY setting

## L

LIVE_TRANSLATION setting | LOOKUP_BACKENDS setting

## M

MARKUP_FILTER setting MAX_AUTOTERMS setting | MIN_AUTOTERMS setting MT_BACKENDS setting

## O

OBJECT_CACHE_TIMEOUT setting

## P

PARSE_POOL_CULL_FREQUENCY setting PARSE_POOL_SIZE setting | PODIRECTORY setting

## S

setting AMAGAMA_URL AUTH_LDAP_ANON_DN AUTH_LDAP_ANON_PASS AUTH_LDAP_BASE_DN AUTH_LDAP_FIELDS AUTH_LDAP_FILTER AUTH_LDAP_SERVER AUTOSYNC CAN_CONTACT CAN_REGISTER CONTACT_EMAIL CUSTOM_TEMPLATE_CONTEXT DESCRIPTION EMAIL_SEND_HTML ENABLE_ALT_SRC EXPORTED_DIRECTORY_MODE EXPORTED_FILE_MODE FUZZY_MATCH_MAX_LENGTH FUZZY_MATCH_MIN_SIMILARITY LIVE_TRANSLATION LOOKUP_BACKENDS MARKUP_FILTER MAX_AUTOTERMS MIN_AUTOTERMS MT_BACKENDS OBJECT_CACHE_TIMEOUT PARSE_POOL_CULL_FREQUENCY PARSE_POOL_SIZE PODIRECTORY TITLE TOPSTAT_SIZE USE_CAPTCHA VCS_DIRECTORY

## T

TITLE setting | TOPSTAT_SIZE setting

## U

USE_CAPTCHA setting

## V

VCS_DIRECTORY setting